@@ -136,9 +136,8 @@ class InMemoryStoreBackend(StoreBackend):
 
 class FixedLengthTupleStoreBackend(StoreBackend):
     """
-
-    The key to this StoreBackend abstract class must be a tuple with fixed length equal to key_length.
-    The filepath_template is a string template used to convert the key to a filepath.
+    If key_length is provided, the key to this StoreBackend abstract class must be a tuple with fixed length equal
+    to key_length. The filepath_template is a string template used to convert the key to a filepath.
     There's a bit of regex magic in _convert_filepath_to_key that reverses this process,
     so that we can write AND read using filenames as keys.
 
@@ -154,7 +153,7 @@ class FixedLengthTupleStoreBackend(StoreBackend):
         forbidden_substrings=None,
         platform_specific_separator=True
     ):
-        assert isinstance(key_length, int)
+        assert isinstance(key_length, int) or key_length is None
         self.key_length = key_length
         if forbidden_substrings is None:
             forbidden_substrings = ["/", "\\"]
@@ -162,7 +161,8 @@ class FixedLengthTupleStoreBackend(StoreBackend):
         self.platform_specific_separator = platform_specific_separator
 
         self.filepath_template = filepath_template
-        self.verify_that_key_to_filepath_operation_is_reversible()
+        if key_length:
+            self.verify_that_key_to_filepath_operation_is_reversible()
 
     def _validate_key(self, key):
         super(FixedLengthTupleStoreBackend, self)._validate_key(key)
@@ -177,12 +177,11 @@ class FixedLengthTupleStoreBackend(StoreBackend):
                     ))
 
     def _validate_value(self, value):
-        # NOTE: We may want to allow bytes here as well.
-
-        if not isinstance(value, string_types):
-            raise TypeError("Values in {0} must be instances of {1}, not {2}".format(
+        if not isinstance(value, string_types) and not isinstance(value, bytes):
+            raise TypeError("Values in {0} must be instances of {1} or {2}, not {3}".format(
                 self.__class__.__name__,
                 string_types,
+                bytes,
                 type(value),
             ))
 
@@ -191,9 +190,13 @@ class FixedLengthTupleStoreBackend(StoreBackend):
         # That seems more correct, but the configs will be a lot less intuitive.
         # In the meantime, there is some chance that configs will not be cross-OS compatible.
 
-        # NOTE : These methods support fixed-length keys, but not variable.
+        # NOTE : These methods support variable-length keys if no filepath template is provided, in which case
+        # all key elements are joined to generate the filepath
         self._validate_key(key)
-        converted_string = self.filepath_template.format(*list(key))
+        if self.filepath_template:
+            converted_string = self.filepath_template.format(*list(key))
+        else:
+            converted_string = '/'.join(key)
         if self.platform_specific_separator:
             converted_string = os.path.join(*converted_string.split('/'))
         return converted_string
@@ -201,6 +204,9 @@ class FixedLengthTupleStoreBackend(StoreBackend):
     def _convert_filepath_to_key(self, filepath):
         # filepath_template (for now) is always specified with forward slashes, but it is then
         # used to (1) dynamically construct and evaluate a regex, and (2) split the provided (observed) filepath
+        if not self.filepath_template:
+            return tuple(filepath.split(os.sep))
+        
         if self.platform_specific_separator:
             filepath_template = os.path.join(*self.filepath_template.split('/'))
             filepath_template = filepath_template.replace('\\', '\\\\')
@@ -305,7 +311,10 @@ class FixedLengthTupleFilesystemStoreBackend(FixedLengthTupleStoreBackend):
 
         safe_mmkdir(str(path))
         with open(filepath, "wb") as outfile:
-            outfile.write(value.encode("utf-8"))
+            if isinstance(value, bytes):
+                outfile.write(value)
+            else:
+                outfile.write(value.encode("utf-8"))
         return filepath
 
     def list_keys(self):
@@ -382,7 +391,7 @@ class FixedLengthTupleS3StoreBackend(FixedLengthTupleStoreBackend):
         s3_response_object = s3.get_object(Bucket=self.bucket, Key=s3_object_key)
         return s3_response_object['Body'].read().decode(s3_response_object.get("ContentEncoding", 'utf-8'))
 
-    def _set(self, key, value, content_encoding='utf-8', content_type='application/json'):
+    def _set(self, key, value, content_encoding='utf-8', content_type='application/json', **kwargs):
         s3_object_key = os.path.join(
             self.prefix,
             self._convert_key_to_filepath(key)
@@ -391,7 +400,11 @@ class FixedLengthTupleS3StoreBackend(FixedLengthTupleStoreBackend):
         import boto3
         s3 = boto3.resource('s3', **self._boto3_options)
         result_s3 = s3.Object(self.bucket, s3_object_key)
-        result_s3.put(Body=value.encode(content_encoding), ContentEncoding=content_encoding, ContentType=content_type)
+        if isinstance(value, string_types):
+            result_s3.put(Body=value.encode(content_encoding), ContentEncoding=content_encoding,
+                          ContentType=content_type)
+        else:
+            result_s3.put(Body=value, ContentType=content_type)
         return s3_object_key
 
     def list_keys(self):
@@ -464,7 +477,7 @@ class FixedLengthTupleGCSStoreBackend(FixedLengthTupleStoreBackend):
         gcs_response_object = bucket.get_blob(gcs_object_key)
         return gcs_response_object.download_as_string().decode("utf-8")
 
-    def _set(self, key, value, content_encoding='utf-8', content_type='application/json'):
+    def _set(self, key, value, content_encoding='utf-8', content_type='application/json', **kwargs):
         gcs_object_key = os.path.join(
             self.prefix,
             self._convert_key_to_filepath(key)
@@ -474,7 +487,15 @@ class FixedLengthTupleGCSStoreBackend(FixedLengthTupleStoreBackend):
         gcs = storage.Client(project=self.project)
         bucket = gcs.get_bucket(self.bucket)
         blob = bucket.blob(gcs_object_key)
-        blob.upload_from_string(value.encode(content_encoding), content_type=content_type)
+        if isinstance(value, string_types):
+            # Following try/except is to support py2, since both str and bytes objects pass above condition
+            try:
+                blob.upload_from_string(value.encode(content_encoding), content_encoding=content_encoding,
+                                        content_type=content_type)
+            except TypeError:
+                blob.upload_from_string(value, content_type=content_type)
+        else:
+            blob.upload_from_string(value, content_type=content_type)
         return gcs_object_key
 
     def list_keys(self):
